# epic
Quick interactive image picking. Can be run interactively using:

`python launch.py` (make sure the correct python env is active ).

You can also launch the tool from scripts or notebooks using:

`pick_single( image )` or `pick_multi( image )`.

Please refer to function docstrings for detailed options, and see the notebook in the tests folder for examples. Epic!
